@@ -82,20 +82,19 @@ def exportPandasToS3(obj,bucket,key):
     # JSON files
     elif fileFormat == ".json":
         if objClass == "keras":
-            with tempfile.TemporaryFile(suffix='.json') as fp:
-                # STILL NOT WORKING? 
-                fp.write(json.dumps(obj.to_json()))    # Error message: a bytes-like object is required, not 'str'
-                fp.seek(0)
-                s3resource.Object(bucket, key).put(Body=fp.read())
-
+            s3resource.Object(bucket, key).put(Body=json.dumps(obj.to_json()).encode())
+        else:
+            raise Exception(raiseString)
+            
     # HDF5 files 
     elif fileFormat == ".h5":
         if objClass == "keras":
-            with tempfile.TemporaryFile(suffix='.h5')  as fp:
-                # STILL NOT WORKING? 
-                obj.save_weights(fp.name)   # Error message: expected str, bytes or os.PathLike object, not int
+            with tempfile.NamedTemporaryFile(suffix='.h5')  as fp:
+                obj.save_weights(fp.name)   
                 fp.seek(0)
                 s3resource.Object(bucket, key).put(Body=fp.read())
+        else:
+            raise Exception(raiseString)
     else:
         raise Exception(raiseString)
 
@@ -161,7 +160,7 @@ def importFileFromS3(bucket, key, objClass="pandas", **kwargs):
             obj = pd.read_pickle(io.BytesIO(S3data), **kwargs)
         elif objClass == "sklearn":
             with tempfile.TemporaryFile() as fp:
-                s3resource.download_fileobj(Bucket=bucket, Key=key,Fileobj=fp)
+                s3client.download_fileobj(Bucket=bucket, Key=key,Fileobj=fp)
                 fp.seek(0)
                 obj = joblib.load(fp)          
         else:
